You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ms...@apache.org on 2020/08/26 18:27:12 UTC

[openoffice] branch AOO42X updated: Fixed typos, removed whitespace

This is an automated email from the ASF dual-hosted git repository.

mseidel pushed a commit to branch AOO42X
in repository https://gitbox.apache.org/repos/asf/openoffice.git


The following commit(s) were added to refs/heads/AOO42X by this push:
     new 58a988d  Fixed typos, removed whitespace
58a988d is described below

commit 58a988d92c9014b775be77867311d144409a6e16
Author: mseidel <ms...@apache.org>
AuthorDate: Wed Aug 26 20:24:45 2020 +0200

    Fixed typos, removed whitespace
    
    (cherry picked from commit c3b7da30377815802429c889b153852f1ce44980)
---
 .../OfficeDev/DesktopEnvironment/DocumentView.java |  16 +--
 .../OfficeDev/DesktopEnvironment/StatusView.java   |  20 ++--
 .../AsciiFilter/FilterOptions.java                 |  20 ++--
 main/offapi/com/sun/star/document/ExportFilter.idl | 117 +++++++++---------
 main/offapi/com/sun/star/document/ImportFilter.idl | 117 +++++++++---------
 main/offapi/com/sun/star/task/XStatusIndicator.idl | 133 +++++++++++----------
 6 files changed, 213 insertions(+), 210 deletions(-)

diff --git a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
index 247ee06..796f884 100644
--- a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
+++ b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -192,7 +192,7 @@ public class DocumentView extends    JFrame
 
     /**
      * Create the view frame for showing the office documents on demand.
-     * Dependend from given command line parameter we create
+     * Dependent from given command line parameter we create
      * an office XFrame and initialize it with a window. This
      * window can be a pure toolkit window (means toolkit of office!)
      * or a plugged java canvas - office window combination.
@@ -200,8 +200,8 @@ public class DocumentView extends    JFrame
     public void createFrame()
     {
         // create view frame (as a XFrame!) here
-        // Look for right view mode setted by user command line parameter.
-        // First try to get a new unambigous frame name from our global ViewContainer.
+        // Look for right view mode set by user command line parameter.
+        // First try to get a new unambiguous frame name from our global ViewContainer.
         if(ViewContainer.mbInplace==true)
         {
             // inplace document view can't be initialized without a visible parent window hierarchy!
@@ -333,7 +333,7 @@ public class DocumentView extends    JFrame
         maInterceptor = null;
 
         // close the frame and his document
-        // Relaesing of our listener connections for disposing()
+        // Releasing of our listener connections for disposing()
         // will be forced automatically then. Because the frame
         // will call us back ...
         if (mxFrame!=null)
diff --git a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
index a792044..53dca6c 100644
--- a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
+++ b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -38,15 +38,15 @@ import java.lang.String;
  * and actualize it automatically if frame broadcast changes of
  * his contained document.
  * Threads are necessary to prevent this view against deadlocks.
- * These deadlocks can occure if a listener will be notified
+ * These deadlocks can occur if a listener will be notified
  * by the office in an "oneway" method and try to call back
  * to the office by using a synchronous method.
  * UNO must guarantee order of all these calls ... and if
  * the source of arrived event holds a mutex and our synchronous
- * call needs this mutex too => a deadlock occure.
+ * call needs this mutex too => a deadlock occur.
  * Why? UNO had created a new thread for our synchronous call
  * inside the office process and so exist different threads
- * for this constallation.
+ * for this constellation.
  *
  * @author     Andreas Schl&uuml;ns
  * @created    20.06.2002 15:08
@@ -197,8 +197,8 @@ public class StatusView extends    JPanel
     // ____________________
 
     /**
-     * Set new frame for this view and start listening for events imedatly.
-     * We create one status listener for every control we whish to update.
+     * Set new frame for this view and start listening for events immediately.
+     * We create one status listener for every control we wish to update.
      * And because the environment of the frame can be changed - these
      * listener refresh himself internally for frame action events too.
      * So we register it as such frame action listener only here.
@@ -214,7 +214,7 @@ public class StatusView extends    JPanel
 
         // create some listener on given frame for available status events
         // Created listener instances will register herself on this frame and
-        // show her received informations automatically on setted UI controls.
+        // show her received informations automatically on set UI controls.
         m_aFontListener      = new StatusListener(m_laFontValue     ,FONT_ON     ,FONT_OFF     ,xFrame, FEATUREURL_FONT     );
         m_aSizeListener      = new StatusListener(m_laSizeValue     ,SIZE_ON     ,SIZE_OFF     ,xFrame, FEATUREURL_SIZE     );
         m_aBoldListener      = new StatusListener(m_laBoldValue     ,BOLD_ON     ,BOLD_OFF     ,xFrame, FEATUREURL_BOLD     );
diff --git a/main/offapi/com/sun/star/document/ExportFilter.idl b/main/offapi/com/sun/star/document/ExportFilter.idl
index 4a4aa27..6008bbb 100644
--- a/main/offapi/com/sun/star/document/ExportFilter.idl
+++ b/main/offapi/com/sun/star/document/ExportFilter.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,19 +7,20 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
+
 #ifndef __com_sun_star_document_ExportFilter_idl__
 #define __com_sun_star_document_ExportFilter_idl__
 
@@ -46,83 +47,83 @@ module com { module sun { module star { module document {
 //=============================================================================
 /** filter for exports
 
-    <p>
-    Such filters can be used for exporting a content.
-    Of course it's possible to combine it with the service <type>ImportFilter</type>
-    if import functionality should be available at same implementation too.
-    </p>
+	<p>
+	Such filters can be used for exporting a content.
+	Of course it's possible to combine it with the service <type>ImportFilter</type>
+	if import functionality should be available at same implementation too.
+	</p>
 
-    @see ImportFilter
+	@see ImportFilter
  */
 published service ExportFilter
 {
 	//-------------------------------------------------------------------------
-    /** set source(!) document for this filter
+	/** set source(!) document for this filter
 
 		<p>
-        The document must be used as the source for following filter operation.
-        Any content from there will be exported to another format.
+		The document must be used as the source for following filter operation.
+		Any content from there will be exported to another format.
 		</p>
 	 */
-    interface XExporter;
+	interface XExporter;
 
 	//-------------------------------------------------------------------------
-    /** filter interface
+	/** filter interface
+
+		<p>
+		It's used to filter a document at saving time.
+		The source document should be already set by using another interface
+		<type>XExporter</type> which is supported by this service too.
+		</p>
 
 		<p>
-        It's used to filter a document at saving time.
-        The source document should be already setted by using another interface
-        <type>XExporter</type> which is supported by this service too.
-        </p>
-
-        <p>
-        Tip:<br>
-        If same implementation provides the service <type>ImportFilter</type> too,
-        code must distinguish between filtering from a source document (for export) or
-        filtering to a target document (for import). This can be recognized by saving
-        state of used interfaces <type>XExporter</type> or <type>XImporter</type>!
-        Otherwise it's not clear which action is required here.
- 		</p>
- 	*/
-    interface XFilter;
+		Tip:<br>
+		If same implementation provides the service <type>ImportFilter</type> too,
+		code must distinguish between filtering from a source document (for export) or
+		filtering to a target document (for import). This can be recognized by saving
+		state of used interfaces <type>XExporter</type> or <type>XImporter</type>!
+		Otherwise it's not clear which action is required here.
+		</p>
+	 */
+	interface XFilter;
 
 	//-------------------------------------------------------------------------
-    /** support initialization of filter with its own configuration
+	/** support initialization of filter with its own configuration
 
 		<p>
-        A filter object must be created by global service <type>FilterFactory</type>.
-        If filter supports this optional interface, he will be initialized by the factory directly
-        after creation. The factory will pass follow informations to this new instance:
-            <ul>
-                <li>first item will be a set of configuration data of the filter</li>
-                <li>after that will follow may given optional parameters of call
-                    <member scope="com::sun::star::lang">XMultiServiceFactory::createInstanceWithArguments()</member>
-                    of service <type>FilterFactory</type>.
-                </li>
-            </ul>
-        See description of service <member>FilterFactory::XNameContainer</member> for a description of
-        possible configuration data.
-        </p>
+		A filter object must be created by global service <type>FilterFactory</type>.
+		If filter supports this optional interface, he will be initialized by the factory directly
+		after creation. The factory will pass follow informations to this new instance:
+			<ul>
+				<li>first item will be a set of configuration data of the filter</li>
+				<li>after that will follow may given optional parameters of call
+					<member scope="com::sun::star::lang">XMultiServiceFactory::createInstanceWithArguments()</member>
+					of service <type>FilterFactory</type>.
+				</li>
+			</ul>
+		See description of service <member>FilterFactory::XNameContainer</member> for a description of
+		possible configuration data.
+		</p>
 	 */
 	[optional] interface com::sun::star::lang::XInitialization;
 
 	//-------------------------------------------------------------------------
-    /** provides access to the internal name of this filter
+	/** provides access to the internal name of this filter
 
 		<p>
-        This internal filter name can be used on service <type>FilterFactory</type>
-        to get further informations about it (e.g. his registration for mime types or extensions etc.)
-        It's important that returned string is the "internal name" of the filter which must be
-        unambigous against all other registered filter in current instalation.
-        </p>
-        <p>
-        <strong>Attention!</strong><br>
-        Supported method setName() sould be ignored or forwarded to the FilterFactory.
-        It's not allowed to set it directly to the configuration. Because it depends
-        from real implementation of the FilterFactory if it will be allowed or not!
- 		</p>
- 	*/
-    [optional] interface com::sun::star::container::XNamed;
+		This internal filter name can be used on service <type>FilterFactory</type>
+		to get further informations about it (e.g. his registration for mime types or extensions etc.)
+		It's important that returned string is the "internal name" of the filter which must be
+		unambiguous against all other registered filter in current installation.
+		</p>
+		<p>
+		<strong>Attention!</strong><br>
+		Supported method setName() should be ignored or forwarded to the FilterFactory.
+		It's not allowed to set it directly to the configuration. Because it depends
+		from real implementation of the FilterFactory if it will be allowed or not!
+		</p>
+	 */
+	[optional] interface com::sun::star::container::XNamed;
 };
 
 //=============================================================================
diff --git a/main/offapi/com/sun/star/document/ImportFilter.idl b/main/offapi/com/sun/star/document/ImportFilter.idl
index fd35225..b97c459 100644
--- a/main/offapi/com/sun/star/document/ImportFilter.idl
+++ b/main/offapi/com/sun/star/document/ImportFilter.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,19 +7,20 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
+
 #ifndef __com_sun_star_document_ImportFilter_idl__
 #define __com_sun_star_document_ImportFilter_idl__
 
@@ -46,83 +47,83 @@ module com { module sun { module star { module document {
 //=============================================================================
 /** filter for imports
 
-    <p>
-    Such filters can be used for importing a content.
-    Of course it's possible to combine it with the service <type>ExportFilter</type>
-    if export functionality should be available at same implementation too.
-    </p>
+	<p>
+	Such filters can be used for importing a content.
+	Of course it's possible to combine it with the service <type>ExportFilter</type>
+	if export functionality should be available at same implementation too.
+	</p>
 
-    @see ExportFilter
+	@see ExportFilter
  */
 published service ImportFilter
 {
 	//-------------------------------------------------------------------------
-    /** set target(!) document for this filter
+	/** set target(!) document for this filter
 
 		<p>
-        The document must be used as the target of the filter.
-        Any external content will be written there.
+		The document must be used as the target of the filter.
+		Any external content will be written there.
 		</p>
 	 */
-    interface XImporter;
+	interface XImporter;
 
 	//-------------------------------------------------------------------------
-    /** filter interface
+	/** filter interface
+
+		<p>
+		It's used to filter a document at loading time.
+		The target document should be already set by using another interface
+		<member>ImportFilter::XImporter</member> which is supported by this service too.
+		</p>
 
 		<p>
-        It's used to filter a document at loading time.
-        The target document should be already setted by using another interface
-        <member>ImportFilter::XImporter</member> which is supported by this service too.
-        </p>
-
-        <p>
-        Tip:<br>
-        If same implementation provides the service <type>ExportFilter</type> too,
-        code must distinguish between filtering into a target document (for import) or
-        filtering from a source document (for export). This can be recognized by saving
-        state of used interfaces <type>XExporter</type> or <type>XImporter</type>!
-        Otherwise it's not clear which action is required here.
- 		</p>
- 	*/
-    interface XFilter;
+		Tip:<br>
+		If same implementation provides the service <type>ExportFilter</type> too,
+		code must distinguish between filtering into a target document (for import) or
+		filtering from a source document (for export). This can be recognized by saving
+		state of used interfaces <type>XExporter</type> or <type>XImporter</type>!
+		Otherwise it's not clear which action is required here.
+		</p>
+	 */
+	interface XFilter;
 
 	//-------------------------------------------------------------------------
-    /** support initialization of filter with its own configuration
+	/** support initialization of filter with its own configuration
 
 		<p>
-        A filter object must be created by global service <type>FilterFactory</type>.
-        If filter supports this optional interface, he will be initialized by the factory directly
-        after creation. The factory will pass follow informations to this new instance:
-            <ul>
-                <li>first item will be a set of configuration data of the filter</li>
-                <li>after that will follow may given optional parameters of call
-                    <member scope="com::sun::star::lang">XMultiServiceFactory::createInstanceWithArguments()</member>
-                    of service <type>FilterFactory</type>.
-                </li>
-            </ul>
-        See description of service <member>FilterFactory::XNameContainer</member> for a description of
-        possible configuration data.
-        </p>
+		A filter object must be created by global service <type>FilterFactory</type>.
+		If filter supports this optional interface, he will be initialized by the factory directly
+		after creation. The factory will pass follow informations to this new instance:
+			<ul>
+				<li>first item will be a set of configuration data of the filter</li>
+				<li>after that will follow may given optional parameters of call
+					<member scope="com::sun::star::lang">XMultiServiceFactory::createInstanceWithArguments()</member>
+					of service <type>FilterFactory</type>.
+				</li>
+			</ul>
+		See description of service <member>FilterFactory::XNameContainer</member> for a description of
+		possible configuration data.
+		</p>
 	 */
 	[optional] interface com::sun::star::lang::XInitialization;
 
 	//-------------------------------------------------------------------------
-    /** provides access to the internal name of this filter
+	/** provides access to the internal name of this filter
 
 		<p>
-        This internal filter name can be used on service <type>FilterFactory</type>
-        to get further informations about it (e.g. his registration for mime types or extensions etc.)
-        It's important that returned string is the "internal name" of the filter which must be
-        unambigous against all other registered filter in current instalation.
-        </p>
-        <p>
-        <strong>Attention!</strong><br>
-        Supported method setName() sould be ignored or forwarded to the FilterFactory.
-        It's not allowed to set it directly to the configuration. Because it depends
-        from real implementation of the FilterFactory if it will be allowed or not!
- 		</p>
- 	*/
-    [optional] interface com::sun::star::container::XNamed;
+		This internal filter name can be used on service <type>FilterFactory</type>
+		to get further informations about it (e.g. his registration for mime types or extensions etc.)
+		It's important that returned string is the "internal name" of the filter which must be
+		unambiguous against all other registered filter in current installation.
+		</p>
+		<p>
+		<strong>Attention!</strong><br>
+		Supported method setName() should be ignored or forwarded to the FilterFactory.
+		It's not allowed to set it directly to the configuration. Because it depends
+		from real implementation of the FilterFactory if it will be allowed or not!
+		</p>
+	 */
+	[optional] interface com::sun::star::container::XNamed;
 };
 
 //=============================================================================
diff --git a/main/offapi/com/sun/star/task/XStatusIndicator.idl b/main/offapi/com/sun/star/task/XStatusIndicator.idl
index 3789eac..7f34042 100644
--- a/main/offapi/com/sun/star/task/XStatusIndicator.idl
+++ b/main/offapi/com/sun/star/task/XStatusIndicator.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,19 +7,20 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
+
 #ifndef __com_sun_star_task_XStatusIndicator_idl__
 #define __com_sun_star_task_XStatusIndicator_idl__
 
@@ -29,94 +30,94 @@
 
 //=============================================================================
 
- module com {  module sun {  module star {  module task {
+ module com { module sun { module star { module task {
 
 //=============================================================================
 /** controls a status indicator which displays progress of
-    longer actions to the user
+	longer actions to the user
 
-    <p>
-    Such objects are provided by a <type>XStatusIndicatorFactory</type>.
-    </p>
+	<p>
+	Such objects are provided by a <type>XStatusIndicatorFactory</type>.
+	</p>
 
-    @see XStatusIndicatorFactory
+	@see XStatusIndicatorFactory
  */
 published interface XStatusIndicator: com::sun::star::uno::XInterface
 {
 	//-------------------------------------------------------------------------
-    /** initialize and start the progress
-
-        <p>
-        It activates a new created or reactivate an already used inidicator
-        (must be finished by calling <member>XStatusIndicator::end()</member>
-        before!). By the way it's possible to set first progress description
-        and the possible range of progress value. That means that a progress
-        can runs from 0 to <var>Range</var>.
-        </p>
-
-        @param Text
-            initial value for progress description for showing
-            Value can be updated by calling <member>XStatusIndicator::setText()</member>.
-
-        @param Range
-            mewns the maximum value of the progress which can be setted by
-            calling <member>XStatusIndicator::setValue()</member>.
+	/** initialize and start the progress
+
+		<p>
+		It activates a new created or reactivate an already used indicator
+		(must be finished by calling <member>XStatusIndicator::end()</member>
+		before!). By the way it's possible to set first progress description
+		and the possible range of progress value. That means that a progress
+		can runs from 0 to <var>Range</var>.
+		</p>
+
+		@param Text
+			initial value for progress description for showing
+			Value can be updated by calling <member>XStatusIndicator::setText()</member>.
+
+		@param Range
+			means the maximum value of the progress which can be set by
+			calling <member>XStatusIndicator::setValue()</member>.
 	 */
-    [oneway] void start(
-        [in] string Text,
-        [in] long Range);
+	[oneway] void start(
+		[in] string Text,
+		[in] long Range);
 
 	//-------------------------------------------------------------------------
-    /** stop the progress
-
-        <p>
-        Further calls of <member>XStatusIndicator::setText()</member>,
-        <member>XStatusIndicator::setValue()</member> or
-        <member>XStatusIndicator::reset()</member> must be ignored.
-        Only <member>XStatusIndicator::start()</member> can reactivate this
-        indicator.
-        It's not allowed to destruct the indicator inside this method.
-        The instance must be gone by using ref count or disposing.
-        </p>
-     */
+	/** stop the progress
+
+		<p>
+		Further calls of <member>XStatusIndicator::setText()</member>,
+		<member>XStatusIndicator::setValue()</member> or
+		<member>XStatusIndicator::reset()</member> must be ignored.
+		Only <member>XStatusIndicator::start()</member> can reactivate this
+		indicator.
+		It's not allowed to destruct the indicator inside this method.
+		The instance must be gone by using ref count or disposing.
+		</p>
+	*/
 	[oneway] void end();
 
 	//-------------------------------------------------------------------------
-    /** update progress description
+	/** update progress description
 
-        <p>
-        Initial value can be set during starting of the progress by calling
-        <member>XStatusIndicator::start()</member>.
-        Stopped indicators must ignore this call.
-        </p>
+		<p>
+		Initial value can be set during starting of the progress by calling
+		<member>XStatusIndicator::start()</member>.
+		Stopped indicators must ignore this call.
+		</p>
 
-        @param Text
-            new value for progress description which should be shown now
+		@param Text
+			new value for progress description which should be shown now
 	 */
-    [oneway] void setText( [in] string Text );
+	[oneway] void setText( [in] string Text );
 
 	//-------------------------------------------------------------------------
-    /** update progress value
+	/** update progress value
 
-        <p>
-        Wrong values must be ignored and stopped indicators must ignore this
-        call generally.
-        </p>
+		<p>
+		Wrong values must be ignored and stopped indicators must ignore this
+		call generally.
+		</p>
 
-        @param Value
-            new value for progress which should be shown now
-            Must fit the range [0..Range] which was set during
-            <member>XStatusIndicator::start()</member>.
+		@param Value
+			new value for progress which should be shown now
+			Must fit the range [0..Range] which was set during
+			<member>XStatusIndicator::start()</member>.
 	 */
-    [oneway] void setValue( [in] long Value );
+	[oneway] void setValue( [in] long Value );
 
 	//-------------------------------------------------------------------------
-    /** clear progress value and description
+	/** clear progress value and description
 
-        <p>
-        Calling of setValue(0) and setText("") should do the same.
-        Stopped indicators must ignore this call.
-        </p>
+		<p>
+		Calling of setValue(0) and setText("") should do the same.
+		Stopped indicators must ignore this call.
+		</p>
 	 */
 	[oneway] void reset();
 };
diff --git a/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java b/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java
index ac43f57..edadbd7 100644
--- a/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java
+++ b/main/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/FilterOptions.java
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -45,8 +45,8 @@ import com.sun.star.lang.IllegalArgumentException;
 
   @attention    This class mustn't be threadsafe - because instances of it
                 are used temp. only - not as members. So no concurrent access
-                should occure.
-                Another reason: It wuold be very difficult to safe every
+                should occur.
+                Another reason: It would be very difficult to safe every
                 access on our internal member. To do so - we must implement
                 special methods instead of allowing pure member access.
  ************************************************************************-*/
@@ -151,7 +151,7 @@ public class FilterOptions
                         if (lFilterProps[p].Name.equals("LowerCase"))
                         {
                             m_bLower      = AnyConverter.toBoolean(lFilterProps[p].Value);
-                            m_bCaseChange = true; // Set it after m_bLower - because an exception can occure and we must use default values then!
+                            m_bCaseChange = true; // Set it after m_bLower - because an exception can occur and we must use default values then!
                         }
                     }
                 }
@@ -159,9 +159,9 @@ public class FilterOptions
             catch(com.sun.star.lang.IllegalArgumentException exConvert)
             {
                 // ONE argument has the wrong type
-                // But I think we mustn't react here - because we setted
+                // But I think we mustn't react here - because we set
                 // default values for every necessary item we need.
-                // In case this exception occures - this default exist
+                // In case this exception occurs - this default exist
                 // and we can live with it.
             }
         }
@@ -195,7 +195,7 @@ public class FilterOptions
      * Note: This method doesn't check for a valid URL. It must be done before.
      *
      * @param bImport
-     *          inidcates which stream member must be valid as result of this call
+     *          indicates which stream member must be valid as result of this call
      */
     private void impl_openStreams( boolean bImport )
     {